@@ -86,7 +86,8 @@ class Profiler(object):
             return exc.HTTPNotFound('Missing profile id to view')
         dir_name = self.profile_path or ''
         fname = os.path.join(dir_name, profile_id) + '.pkl'
-        data = cPickle.load(open(fname, 'rb'))
+        with open(fname, 'rb') as f:
+            data = cPickle.load(f)
         top = [x for x in data['profile'].values() if not x.get('callers')]
         res = Response()
         res.body = self.render('/show_profile.mako', time=data['time'],
@@ -99,13 +100,14 @@ class Profiler(object):
         dir_name = self.profile_path
         profiles = []
         errors = []
-        max_cost = 0
+        max_cost = 1 # avoid division by zero
         for profile_file in os.listdir(dir_name):
             if profile_file.endswith('.pkl'):
                 path = os.path.join(self.profile_path, profile_file)
                 modified = os.stat(path).st_mtime
                 try:
-                    data = cPickle.load(open(path, 'rb'))
+                    with open(path, 'rb') as f:
+                        data = cPickle.load(f)
                 except Exception as e:
                     errors.append((modified, '%s: %s' % (e.__class__.__name__, e), profile_file[:-4]))
                 else:
@@ -116,8 +118,6 @@ class Profiler(object):
                     else:
                         total_cost = 0
                     max_cost = max(max_cost, total_cost)
-                    if max_cost == 0:
-                        max_cost = 1 # avoid division by zero
                     profiles.append((modified, environ, total_cost, profile_file[:-4]))
 
         profiles.sort(reverse=True)
@@ -196,11 +196,12 @@ class Profiler(object):
                            environ=safe_environ)
         dir_name = self.profile_path or ''
 
+        openflags = os.O_WRONLY | os.O_CREAT | os.O_EXCL | getattr(os, 'O_BINARY', 0)
         while True:
             fname_base = str(time.time()).replace('.', '_')
             prof_file = fname_base + '.pkl'
             try:
-                os.open(os.path.join(dir_name, prof_file), os.O_CREAT | os.O_EXCL)
+                fd = os.open(os.path.join(dir_name, prof_file), openflags)
             except OSError as e:
                 if e.errno == errno.EEXIST:
                     # file already exists, try again with a slightly different
@@ -211,7 +212,7 @@ class Profiler(object):
             else:
                 break
 
-        with open(os.path.join(dir_name, prof_file), 'wb') as f:
+        with os.fdopen(fd, 'wb') as f:
             cPickle.dump(profile_run, f)
         write_dot_graph(results, tree, os.path.join(dir_name, fname_base+'.gv'),
                         cutoff=self.dot_graph_cutoff)
