@@ -27,7 +27,7 @@ class EvilProxyClass(object):
         self.obj = obj
 
     @property
-    def __module__(self):
+    def __module__(self):  # pragma: nocover
         return self.obj.__module__
 
     @property
@@ -63,7 +63,7 @@ class TestDozer(unittest.TestCase):
             target = getattr(dozer.runthread, '_Thread__target',
                              getattr(dozer.runthread, '_target', '???'))
             self.assertEqual(target, dozer.start)
-            dozer.runthread.start.assert_called_once()
+            self.assertEqual(dozer.runthread.start.call_count, 1)
 
     def test_maybe_warn_about_PIL(self):
         with patch('dozer.leak.Dozer._start_thread'):
@@ -172,6 +172,12 @@ class TestEntireStack(unittest.TestCase):
         resp = app.get('/')
         self.assertTrue('hello, world!' in resp)
 
+    def test_dozer(self):
+        app = self.make_test_app()
+        resp = app.get('/_dozer')
+        self.assertEqual(resp.status_int, 200)
+        self.assertTrue('<div id="output">' in resp)
+
     def test_dozer_index(self):
         app = self.make_test_app()
         resp = app.get('/_dozer/index')
